@@ -67,7 +67,7 @@ class Estimator:
         if b_coeff is None:
             b_coeff = self.src_backward()
         est_coeff = self.conj_grad(b_coeff, tol=tol)
-        est = self.basis.evaluate(est_coeff)
+        est = self.basis.evaluate(est_coeff).T
 
         return Volume(est)
 
@@ -85,7 +85,7 @@ class Estimator:
             batch_mean_b = self.src.im_backward(im, i) / self.n
             mean_b += batch_mean_b.astype(self.dtype)
 
-        res = self.basis.evaluate_t(mean_b.T)  # RCOPT
+        res = self.basis.evaluate_t(mean_b)
         logger.info(f"Determined adjoint mappings. Shape = {res.shape}")
         return res
 
@@ -138,8 +138,8 @@ class Estimator:
         """
         if kernel is None:
             kernel = self.kernel
-        vol = self.basis.evaluate(vol_coeff).T  # RCOPT
+        vol = self.basis.evaluate(vol_coeff)
         vol = kernel.convolve_volume(vol)
-        vol = self.basis.evaluate_t(vol.T)  # RCOPT
+        vol = self.basis.evaluate_t(vol)
 
         return vol
