@@ -5,6 +5,7 @@ from .matrix import (
     anorm,
     eigs,
     im_to_vec,
+    make_psd,
     make_symmat,
     mat_to_vec,
     mdim_mat_fun_conj,
@@ -21,4 +22,5 @@ from .matrix import (
     vol_to_vec,
     volmat_to_vecmat,
 )
+from .rotation import Rotation
 from .types import complex_type, real_type, utest_tolerance
